@@ -1,7 +1,7 @@
 """
 Type annotations for codeguru-reviewer service type definitions.
 
-[Open documentation](./type_defs.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/type_defs.html)
 
 Usage::
 
